#Conditionally import wlstModule only when script is executed with jython
if __name__ == '__main__': 
    from wlstModule import *#@UnusedWildImport
    


######################################################################################
# ELJMSCacheCoordination - WLST Script For Setting Up The WebLogic Server Domain     #
#                                                                                    #
# Author: Reinhard Girstenbrei, Oracle Corporation                                   #
#                                                                                    #
# Configuration in: weblogic.properties                                              #
#                                                                                    #
######################################################################################



def loadProperties():
    propertiesInputStream = java.io.FileInputStream("weblogic.properties")
    properties = java.util.Properties()      
    properties.load(propertiesInputStream)
    propertiesInputStream = java.io.FileInputStream("project.properties")
    properties.load(propertiesInputStream)
    return properties

def configureMachine(machineName, listenAddress, listenPort):
    try:
        print "Creating Machine \"" + machineName + "\""
        cd('/')
        cmo.createMachine(machineName)
        cd('/Machines/' + machineName + '/NodeManager/' + machineName)
        cmo.setNMType('SSL')
        cmo.setListenAddress(listenAddress)
        cmo.setListenPort(int(listenPort))
        cmo.setDebugEnabled(false)
    except Exception, e:
        print "Error: Machine \"" + machineName + "\" does already exist"
    print ""

def configureCluster(clusterName):
    try:
        print "Creating Cluster \"" + clusterName + "\""
        cd('/')
        cmo.createCluster(clusterName)
        cd('/Clusters/' + clusterName)
        cmo.setClusterMessagingMode('unicast')
    except Exception, e:
        print "Error: Cluster \"" + clusterName + "\" does already exist"
    print ""

def configureManagedServer(transportProtocol, serverName, listenAddress, listenPort, username, password, clusterName, machineName):
    try:
        print "Creating Managed Server \"" + serverName + "\"" 
        cd('/')
        cmo.createServer(serverName)
        cd('/Servers/' + serverName)
        cmo.setListenAddress(listenAddress)
        cmo.setListenPort(int(listenPort))
        cmo.setCluster(getMBean('/Clusters/' + clusterName))
        cmo.setListenPortEnabled(true)
        cmo.setJavaCompiler('javac')
        cmo.setClientCertProxyEnabled(false)
        cmo.setMachine(getMBean('/Machines/' + machineName))
        cd('/Servers/' + serverName +'/SSL/' + serverName)
        cmo.setEnabled(false)
        cd('/Servers/'+ serverName + '/ServerDiagnosticConfig/' + serverName)
        cmo.setWLDFDiagnosticVolume('Low')
        if (transportProtocol != "no-cc"):
           jvmArgs = '-Declipselink.coordination.localhost=' + str(listenAddress) \
              + ' -Declipselink.coordination.localport=' + str(listenPort) \
              + ' -Declipselink.coordination.username=' + str(username) \
              + ' -Declipselink.coordination.password=' + str(password)
           cd('/Servers/' + serverName + '/ServerStart/' + serverName)
           cmo.setArguments(jvmArgs)
    except Exception, e:
        print "Error: Managed Server \"" + serverName + "\" does already exist"
    print ""
        
def configureJMSServer(jmsServerName, serverName):
    try:   
        print "Creating JMS Server \"" + jmsServerName + "\""
        cd('/')
        cmo.createJMSServer(jmsServerName)
        cd('/Deployments/' +  jmsServerName)
        set('Targets', jarray.array([ObjectName('com.bea:Name=' + serverName + ',Type=Server')], ObjectName))
    except Exception, e:
        print "Error: JMSServer \"" + jmsServerName + "\" does already exist"
    print ""
        

def configureJMSModule(moduleName, clusterName):
    try:
        print "Creating JMS Module \"" + moduleName + "\""
        cd('/')
        cmo.createJMSSystemResource(moduleName)
        cd('/SystemResources/' + moduleName)
        set('Targets', jarray.array([ObjectName('com.bea:Name=' + clusterName + ',Type=Cluster')], ObjectName))
    except Exception, e:
        print "Error: JMS Module \"" + moduleName + "\" does already exist"
    print ""
    
def configureJMSConnectionFactory(factoryName, factoryJNDI, moduleName):
    try: 
        print "Creating Connection Factory \"" + factoryName + "\" "
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName)
        cmo.createConnectionFactory(factoryName)
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/ConnectionFactories/' + factoryName)
        cmo.setJNDIName(factoryJNDI)
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/ConnectionFactories/' + factoryName + '/SecurityParams/' + factoryName)
        cmo.setAttachJMSXUserId(false)
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/ConnectionFactories/' + factoryName + '/ClientParams/' + factoryName)
        cmo.setClientIdPolicy('Restricted')
        cmo.setSubscriptionSharingPolicy('Exclusive')
        cmo.setMessagesMaximum(10)
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/ConnectionFactories/' + factoryName + '/TransactionParams/' + factoryName)
        cmo.setXAConnectionFactoryEnabled(false)
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/ConnectionFactories/' + factoryName)
        cmo.setDefaultTargetingEnabled(true)
    except Exception, e:
        print "Error: JMS Connection Factory \"" + factoryName + "\" does already exist"
    print ""
        
def configureJMSDistributedTopic(topicName, topicJNDI, moduleName):
    try:
        print "Creating Distributed Topic \"" + topicName + "\""
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName)
        cmo.createUniformDistributedTopic(topicName)
        
        cd('/JMSSystemResources/' + moduleName + '/JMSResource/' + moduleName + '/UniformDistributedTopics/' + topicName)
        cmo.setJNDIName(topicJNDI)
        cmo.setForwardingPolicy('Replicated')
        cmo.setDefaultTargetingEnabled(true)
    except Exception, e:
        print "Error: JMS Topic \"" + topicName + "\" does already exist"
    print ""

        
def configureGenericDatasource (datasourceClassName, datasourceName, datasourceJNDI, username, password, url, clusterName):
    try:
        print "Creating Generic DataSource \"" + datasourceName + "\""
        cd('/')
        cmo.createJDBCSystemResource(datasourceName)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName)
        cmo.setName(datasourceName)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDataSourceParams/' + datasourceName)
        set('JNDINames',jarray.array([String(datasourceJNDI)], String))
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName)
        cmo.setUrl(url)
        cmo.setDriverName(datasourceClassName)
        cmo.setPassword(password)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCConnectionPoolParams/' + datasourceName)
        cmo.setTestTableName('SQL SELECT 1 FROM DUAL\r\n')
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName + '/Properties/' + datasourceName)
        cmo.createProperty('user')
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName + '/Properties/' + datasourceName + '/Properties/user')
        cmo.setValue(username)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDataSourceParams/' + datasourceName)
        cmo.setGlobalTransactionsProtocol('TwoPhaseCommit')
    
        cd('/SystemResources/' + datasourceName)
        set('Targets',jarray.array([ObjectName('com.bea:Name=' + clusterName + ',Type=Cluster')], ObjectName))
    except Exception, e:
        print "Error: Generic Datasource \"" + datasourceName + "\" does already exist"
	print ""

def startupCluster(clusterName):
	try:    
		print "Starting up \"" + clusterName + "\""
		cd('/')
		start(clusterName, 'Cluster',block='false')
	except Exception, e:
		print "Error: Starting up \"" + clusterName + "\" failed"
	print ""
	
# =========== Main ===============
redirect(System.getProperty('user.dir') + '/setup_wlst.log')
print "*************************************************************"
print "*** Creating a Cluster With Two Nodes On The Same Machine ***"
print "*************************************************************"
print

properties = loadProperties()

# Connect - interactive

#connect()

# Connect - hard coded

connect(
   properties.get('weblogic.admin.username'), 
   properties.get('weblogic.admin.password'), 
   properties.get('weblogic.admin.url'))

edit()
startEdit()
   
configureMachine(
   properties.get('weblogic.machine'),
   properties.get('weblogic.machine.listen.address'),
   properties.get('weblogic.machine.listen.port'))
   
configureCluster(
   properties.get('weblogic.cluster'))
   
configureManagedServer(
   properties.get('eclipselink.transport.protocol'),
   properties.get('weblogic.managed.server1'),
   properties.get('weblogic.managed.server1.listen.address'),
   properties.get('weblogic.managed.server1.listen.port'),
   properties.get('weblogic.coordination.username'),
   properties.get('weblogic.coordination.password'),
   properties.get('weblogic.cluster'),
   properties.get('weblogic.machine'))

   
configureManagedServer(
   properties.get('eclipselink.transport.protocol'),
   properties.get('weblogic.managed.server2'),
   properties.get('weblogic.managed.server2.listen.address'),
   properties.get('weblogic.managed.server2.listen.port'),
   properties.get('weblogic.coordination.username'),
   properties.get('weblogic.coordination.password'),
   properties.get('weblogic.cluster'),
   properties.get('weblogic.machine'))
   
configureManagedServer(
   properties.get('eclipselink.transport.protocol'),
   properties.get('weblogic.managed.server3'),
   properties.get('weblogic.managed.server3.listen.address'),
   properties.get('weblogic.managed.server3.listen.port'),
   properties.get('weblogic.coordination.username'),
   properties.get('weblogic.coordination.password'),
   properties.get('weblogic.cluster'),
   properties.get('weblogic.machine'))

if (properties.get('eclipselink.transport.protocol') == 'jms' or properties.get('eclipselink.transport.protocol') == 'jms-el22'):
   configureJMSServer(
      properties.get('weblogic.jms.server1'),
      properties.get('weblogic.managed.server1'))

   configureJMSServer(
      properties.get('weblogic.jms.server2'),
      properties.get('weblogic.managed.server2'))

   configureJMSServer(
      properties.get('weblogic.jms.server3'),
      properties.get('weblogic.managed.server3'))

   configureJMSModule(
      properties.get('weblogic.jms.module'),
      properties.get('weblogic.cluster'))

   configureJMSConnectionFactory(
      properties.get('weblogic.jms.connection.factory'),
      properties.get('weblogic.jms.connection.factory.jndi'),
      properties.get('weblogic.jms.module'))

   configureJMSDistributedTopic(
      properties.get('weblogic.jms.distributed.topic'),
      properties.get('weblogic.jms.distributed.topic.jndi'),
      properties.get('weblogic.jms.module'))

print ""   
save()
activate(block="true")

edit()
startEdit()

configureGenericDatasource(
   properties.get('weblogic.datasource.classname'),
   properties.get('weblogic.datasource'),
   properties.get('weblogic.datasource.jndi'),
   properties.get('database.username'),
   properties.get('database.password'),
   properties.get('database.url'),
   properties.get('weblogic.cluster'))

print ""   
save()
activate(block="true")

startupCluster(
   properties.get('weblogic.cluster'))

stopRedirect()
disconnect()
print""
print "*************************************************************"
print "Script finished."
print "*************************************************************"
