
#Conditionally import wlstModule only when script is executed with jython
if __name__ == '__main__': 
    from wlstModule import *#@UnusedWildImport


######################################################################################
# ELJMSCacheCoordination - WLST Script For Cleaning Up The WebLogic Server Domain    #
#                                                                                    #
# Author: Reinhard Girstenbrei, Oracle Corporation                                   #
#                                                                                    #
# Configuration in: weblogic.properties                                              #
#                                                                                    #
######################################################################################


def loadProperties():
    propertiesInputStream = java.io.FileInputStream("weblogic.properties")
    properties = java.util.Properties()      
    properties.load(propertiesInputStream)
    propertiesInputStream = java.io.FileInputStream("project.properties")
    properties.load(propertiesInputStream)
    return properties





def removeJMSModule(moduleName):
    try:
        print "Destroying \"" + moduleName + "\""
        cd('/')
        cmo.destroyJMSSystemResource(getMBean('/SystemResources/' + moduleName))
    except Exception, e:
        print "Error: JMS Module \"" + moduleName + "\" does not exist"
    print ""

def removeJMSServer(jmsServerName):
    try:
        print "Destroying \"" + jmsServerName + "\""
        cmo.destroyJMSServer(getMBean('/Deployments/' + jmsServerName))
    except Exception, e:
        print "Error: JMS Server \"" + jmsServerName + "\" does not exist"
    print ""
 
def removeGenericDatasource(datasourceName):
    try:
        print "Destroying Generic Datasource \"" + datasourceName + "\""
        cmo.destroyJDBCSystemResource(getMBean('/SystemResources/' + datasourceName))
    except Exception, e:
        print e
        print "Error: Generic Datasource \"" + datasourceName + "\" does not exist"
    print ""
    
def removeManagedServer(serverName):
    try:
        print "Destroying Managed Server \"" + serverName + "\""
        cd('/Servers/' + serverName)
        cmo.setCluster(None)
        cmo.setMachine(None)
        editService.getConfigurationManager().removeReferencesToBean(getMBean('/Servers/' + serverName))
        cd('/')
        cmo.destroyServer(getMBean('/Servers/' + serverName))
    except Exception, e:
        print "Error: Managed Server \"" + serverName + "\" does not exist"
    print ""


def removeCluster(clusterName):
    try:    
        print "Destroying \"" + clusterName + "\""
        editService.getConfigurationManager().removeReferencesToBean(getMBean('/Clusters/' + clusterName))
        cmo.destroyCluster(getMBean('/Clusters/' + clusterName))
    except Exception, e:
        print "Error: Cluster \"" + clusterName + "\" does not exist"
    print ""

def removeMachine(machineName):    
    try:    
        print "Destroying \"" + machineName + "\""
        editService.getConfigurationManager().removeReferencesToBean(getMBean('/Machines/' + machineName))
        cmo.destroyMachine(getMBean('/Machines/' + machineName))
    except Exception, e:
        print "Error: Machine \"" + machineName + "\" does not exist"
    print ""
	
def shutdownCluster(clusterName):
    try:
        print "Shutting down \"" + clusterName + "\""
        shutdown(name=clusterName, entityType='Cluster', ignoreSessions='true', timeOut=1000, force='true')
    except Exception, e:
        print "Error: Shutdown of \"" + clusterName + "\" failed"
    print ""
		
    
    

# =========== Main ===============
redirect(System.getProperty('user.dir') + '/teardown_wlst.log')
print "*************************************************************"
print "*** Removing a Cluster With Two Nodes On The Same Machine ***"
print "*************************************************************"
print

properties = loadProperties()

# Connect - interactive

#connect()

# Connect - hard coded

connect(
   properties.get('weblogic.admin.username'), 
   properties.get('weblogic.admin.password'), 
   properties.get('weblogic.admin.url'))


shutdownCluster(
   properties.get('weblogic.cluster'))
   
edit()
startEdit()

if (properties.get('eclipselink.transport.protocol') == 'jms' or properties.get('eclipselink.transport.protocol') == 'jms-el22'):
   removeJMSModule(
      properties.get('weblogic.jms.module'))
   removeJMSServer(
      properties.get('weblogic.jms.server1'))
   removeJMSServer(
      properties.get('weblogic.jms.server2'))
   removeJMSServer(
      properties.get('weblogic.jms.server3'))
   
	  
removeGenericDatasource(
   properties.get('weblogic.datasource'))
removeManagedServer(
   properties.get('weblogic.managed.server1'))
removeManagedServer(
   properties.get('weblogic.managed.server2'))
removeManagedServer(
   properties.get('weblogic.managed.server3'))
removeCluster(
   properties.get('weblogic.cluster'))
removeMachine(
   properties.get('weblogic.machine'))


print ""   
save()
activate(block="true")
stopRedirect()
disconnect()
print""
print "*************************************************************"
print "Script finished."
print "*************************************************************"
